@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -48,7 +48,7 @@
 #include <docfld.hxx>
 #include <unofldmid.h>
 namespace binfilter {
-extern String& GetString( const ::com::sun::star::uno::Any& rAny, String& rStr ); //STRIP008
+extern String& GetString( const ::com::sun::star::uno::Any& rAny, String& rStr );
 
 using namespace ::com::sun::star::sdbc;
 using namespace ::com::sun::star;
@@ -72,21 +72,22 @@ using namespace ::rtl;
     Beschreibung: DatenbankFeldTyp
  --------------------------------------------------------------------*/
 
-/*N*/ SwDBFieldType::SwDBFieldType(SwDoc* pDocPtr, const String& rNam, const SwDBData& rDBData ) :
-/*N*/ 	SwValueFieldType( pDocPtr, RES_DBFLD ),
-/*N*/ 	aDBData(rDBData),
-/*N*/ 	nRefCnt(0),
-/*N*/ 	sColumn(rNam)
-/*N*/ {
-/*N*/     if(aDBData.sDataSource.getLength() || aDBData.sCommand.getLength())
-/*N*/     {
-/*N*/         sName =  aDBData.sDataSource;
-/*N*/         sName += DB_DELIM;
-/*N*/         sName += (String)aDBData.sCommand;
-/*N*/         sName += DB_DELIM;
-/*N*/     }
-/*N*/ 	sName += GetColumnName();
-/*N*/ }
+SwDBFieldType::SwDBFieldType(SwDoc* pDocPtr, const String& rNam, const SwDBData& rDBData )
+    : SwValueFieldType( pDocPtr, RES_DBFLD )
+    , aDBData(rDBData)
+    , nRefCnt(0)
+    , sColumn(rNam)
+{
+    if(aDBData.sDataSource.getLength() || aDBData.sCommand.getLength())
+    {
+        sName =  aDBData.sDataSource;
+        sName += DB_DELIM;
+        sName += (String)aDBData.sCommand;
+        sName += DB_DELIM;
+    }
+    sName += GetColumnName();
+}
+
 //------------------------------------------------------------------------------
 
 /*N*/ SwFieldType* SwDBFieldType::Copy() const
@@ -105,12 +106,12 @@ using namespace ::rtl;
 
 /*N*/ void SwDBFieldType::ReleaseRef()
 /*N*/ {
-/*N*/ 	ASSERT(nRefCnt > 0, "RefCount kleiner 0!");
-/*N*/ 
+/*N*/ 	OSL_ENSURE(nRefCnt > 0, "RefCount kleiner 0!");
+/*N*/
 /*N*/ 	if (--nRefCnt <= 0)
 /*N*/ 	{
 /*N*/ 		USHORT nPos = GetDoc()->GetFldTypes()->GetPos(this);
-/*N*/ 
+/*N*/
 /*N*/ 		if (nPos != USHRT_MAX)
 /*N*/ 		{
 /*N*/ 			GetDoc()->RemoveFldType(nPos);
@@ -119,12 +120,10 @@ using namespace ::rtl;
 /*N*/ 	}
 /*N*/ }
 
-/* -----------------24.02.99 14:51-------------------
- *
- * --------------------------------------------------*/
+
 /*N*/ BOOL SwDBFieldType::QueryValue( ::com::sun::star::uno::Any& rAny, BYTE nMId ) const
 /*N*/ {
-/*N*/     nMId &= ~CONVERT_TWIPS;
+/*N*/   nMId &= ~CONVERT_TWIPS;
 /*N*/ 	switch( nMId )
 /*N*/ 	{
 /*N*/ 	case FIELD_PROP_PAR2:
@@ -140,13 +139,11 @@ using namespace ::rtl;
 /*N*/ 		rAny <<= aDBData.nCommandType;
 /*N*/ 		break;
 /*N*/ 	default:
-/*?*/ 		DBG_ERROR("illegal property");
+/*?*/ 		OSL_FAIL("illegal property");
 /*N*/ 	}
 /*N*/ 	return TRUE;
 /*N*/ }
-/* -----------------24.02.99 14:51-------------------
- *
- * --------------------------------------------------*/
+
 /*N*/ BOOL SwDBFieldType::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId )
 /*N*/ {
 /*N*/     nMId &= ~CONVERT_TWIPS;
@@ -186,7 +183,7 @@ using namespace ::rtl;
 /*N*/ 		rAny >>= aDBData.nCommandType;
 /*N*/ 		break;
 /*N*/ 	default:
-/*?*/ 		DBG_ERROR("illegal property");
+/*?*/ 		OSL_FAIL("illegal property");
 /*N*/ 	}
 /*N*/ 	return TRUE;
 /*N*/ }
@@ -254,11 +251,11 @@ using namespace ::rtl;
 /*N*/ 	String sOldExpand = Expand();
 /*N*/ 	String sNewExpand = sOldExpand;
 /*N*/ 	BOOL bOldInit = bInitialized;
-/*N*/ 
+/*N*/
 /*N*/ 	bInitialized = FALSE;
 /*N*/ 	InitContent();
 /*N*/ 	bInitialized = bOldInit;
-/*N*/ 
+/*N*/
 /*N*/ 	if( ::binfilter::GetAppCmpStrIgnore().isEqual( sNewExpand, Expand() ) )
 /*N*/ 	{
 /*N*/ 		sNewExpand = '<';
@@ -266,7 +263,7 @@ using namespace ::rtl;
 /*N*/ 		sNewExpand += '>';
 /*N*/ 	}
 /*N*/ 	SetExpansion( sOldExpand );
-/*N*/ 
+/*N*/
 /*N*/ 	return sNewExpand;
 /*N*/ }
 
@@ -291,7 +288,7 @@ using namespace ::rtl;
 /*N*/ 	pTmp->bInitialized	= bInitialized;
 /*N*/ 	pTmp->nSubType		= nSubType;
 /*N*/ 	pTmp->SetValue(GetValue());
-/*N*/ 
+/*N*/
 /*N*/ 	return pTmp;
 /*N*/ }
 
@@ -321,14 +318,6 @@ SwFieldType* SwDBField::ChgTyp( SwFieldType* pNewType )
     return pOld;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung: Aktuellen Field-Value holen und chachen
- --------------------------------------------------------------------*/
-
-/*N*/ void SwDBField::Evaluate()
- /*N*/ {    DBG_ERROR("STRIP");
-/*N*/ }
-
 /*--------------------------------------------------------------------
     Beschreibung: Namen erfragen
  --------------------------------------------------------------------*/
@@ -356,9 +345,7 @@ const String& SwDBField::GetPar1() const
 /*N*/ 	nSubType = nType;
 /*N*/ }
 
-/*-----------------06.03.98 16:15-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwDBField::QueryValue( ::com::sun::star::uno::Any& rAny, BYTE nMId ) const
 /*N*/ {
 /*N*/     nMId &= ~CONVERT_TWIPS;
@@ -383,14 +370,12 @@ const String& SwDBField::GetPar1() const
 /*?*/ 		rAny <<= OUString(aContent);
 /*?*/ 		break;
 /*?*/ 	default:
-/*?*/ 		DBG_ERROR("illegal property");
+/*?*/ 		OSL_FAIL("illegal property");
 /*N*/ 	}
 /*N*/ 	return TRUE;
-/*N*/ 
+/*N*/
 /*N*/ }
-/*-----------------06.03.98 16:15-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwDBField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId )
 /*N*/ {
 /*N*/     nMId &= ~CONVERT_TWIPS;
@@ -403,9 +388,9 @@ const String& SwDBField::GetPar1() const
 /*N*/ 			SetSubType(GetSubType()|SUB_OWN_FMT);
 /*N*/ 		break;
 /*N*/     case FIELD_PROP_BOOL2:
-/*N*/     {    
+/*N*/     {
 /*N*/         USHORT nSubType = GetSubType();
-/*N*/         sal_Bool bVisible;
+/*N*/         sal_Bool bVisible(false);
 /*N*/         if(!(rAny >>= bVisible))
 /*N*/             return FALSE;
 /*N*/         if(bVisible)
@@ -413,9 +398,9 @@ const String& SwDBField::GetPar1() const
 /*N*/         else
 /*N*/             nSubType |= SUB_INVISIBLE;
 /*N*/         SetSubType(nSubType);
-/*N*/         //invalidate text node 
+/*N*/         //invalidate text node
 /*N*/         if(GetTyp())
-/*N*/         {        
+/*N*/         {
 /*N*/             SwClientIter aIter( *GetTyp() );
 /*N*/             SwFmtFld* pFld = (SwFmtFld*)aIter.First( TYPE( SwFmtFld ));
 /*N*/             while(pFld)
@@ -434,7 +419,7 @@ const String& SwDBField::GetPar1() const
 /*N*/     break;
 /*N*/ 	case FIELD_PROP_FORMAT:
 /*N*/ 		{
-/*N*/ 			sal_Int32 nTemp;
+/*N*/ 			sal_Int32 nTemp(0);
 /*N*/ 			rAny >>= nTemp;
 /*N*/ 			SetFormat(nTemp);
 /*N*/ 		}
@@ -443,7 +428,7 @@ const String& SwDBField::GetPar1() const
 /*N*/ 		::binfilter::GetString( rAny, aContent );
 /*N*/ 		break;
 /*N*/ 	default:
-/*?*/ 		DBG_ERROR("illegal property");
+/*?*/ 		OSL_FAIL("illegal property");
 /*N*/ 	}
 /*N*/ 	return TRUE;
 /*N*/ }
@@ -452,12 +437,12 @@ const String& SwDBField::GetPar1() const
     Beschreibung: Basisklasse fuer alle weiteren Datenbankfelder
  --------------------------------------------------------------------*/
 
-/*N*/ SwDBNameInfField::SwDBNameInfField(SwFieldType* pTyp, const SwDBData& rDBData, ULONG nFmt) :
-/*N*/ 	SwField(pTyp, nFmt),
-/*N*/     aDBData(rDBData),
-/*N*/     nSubType(0)
-/*N*/ {
-/*N*/ }
+SwDBNameInfField::SwDBNameInfField(SwFieldType* pTyp, const SwDBData& rDBData, ULONG nFmt)
+    : SwField(pTyp, nFmt)
+    , aDBData(rDBData)
+    , nSubType(0)
+{
+}
 
 //------------------------------------------------------------------------------
 
@@ -473,9 +458,7 @@ const String& SwDBField::GetPar1() const
 
 //------------------------------------------------------------------------------
 
-/*-----------------06.03.98 16:55-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwDBNameInfField::QueryValue( ::com::sun::star::uno::Any& rAny, BYTE nMId ) const
 /*N*/ {
 /*N*/     nMId &= ~CONVERT_TWIPS;
@@ -497,13 +480,11 @@ const String& SwDBField::GetPar1() const
 /*N*/     }
 /*N*/     break;
 /*N*/ 	default:
-/*?*/ 		DBG_ERROR("illegal property");
+/*?*/ 		OSL_FAIL("illegal property");
 /*N*/ 	}
 /*N*/ 	return TRUE;
 /*N*/ }
-/*-----------------06.03.98 16:55-------------------
 
---------------------------------------------------*/
 BOOL SwDBNameInfField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId )
 {
     nMId &= ~CONVERT_TWIPS;
@@ -519,9 +500,9 @@ BOOL SwDBNameInfField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nM
         rAny >>= aDBData.nCommandType;
         break;
     case FIELD_PROP_BOOL2:
-    {    
+    {
         USHORT nSubType = GetSubType();
-        sal_Bool bVisible;
+        sal_Bool bVisible(sal_False);
         if(!(rAny >>= bVisible))
             return FALSE;
         if(bVisible)
@@ -532,7 +513,7 @@ BOOL SwDBNameInfField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nM
     }
     break;
     default:
-        DBG_ERROR("illegal property");
+        OSL_FAIL("illegal property");
     }
     return TRUE;
 }
@@ -542,7 +523,7 @@ BOOL SwDBNameInfField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nM
 /*N*/ USHORT SwDBNameInfField::GetSubType() const
 /*N*/ {
 /*N*/     return nSubType;
-/*N*/ }        
+/*N*/ }
 /* -----------------4/10/2003 15:03------------------
 
  --------------------------------------------------*/
@@ -555,10 +536,10 @@ BOOL SwDBNameInfField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nM
     Beschreibung: NaechsterDatensatz
  --------------------------------------------------------------------*/
 
-/*N*/ SwDBNextSetFieldType::SwDBNextSetFieldType()
-/*N*/ 	: SwFieldType( RES_DBNEXTSETFLD )
-/*N*/ {
-/*N*/ }
+SwDBNextSetFieldType::SwDBNextSetFieldType()
+    : SwFieldType( RES_DBNEXTSETFLD )
+{
+}
 
 //------------------------------------------------------------------------------
 
@@ -571,12 +552,15 @@ BOOL SwDBNameInfField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nM
     Beschreibung: SwDBSetField
  --------------------------------------------------------------------*/
 
-/*N*/ SwDBNextSetField::SwDBNextSetField(SwDBNextSetFieldType* pTyp,
-/*N*/ 								   const String& rCond,
-/*N*/ 								   const String& rDummy,
-/*N*/ 								   const SwDBData& rDBData) :
-/*N*/ 	SwDBNameInfField(pTyp, rDBData), aCond(rCond), bCondValid(TRUE)
-/*N*/ {}
+SwDBNextSetField::SwDBNextSetField(
+    SwDBNextSetFieldType* pTyp,
+    const String& rCond,
+    const String& /*rDummy*/ ,
+    const SwDBData& rDBData
+)   : SwDBNameInfField( pTyp, rDBData )
+    , aCond( rCond )
+    , bCondValid( TRUE )
+{}
 
 //------------------------------------------------------------------------------
 
@@ -620,9 +604,7 @@ void SwDBNextSetField::SetPar1(const String& rStr)
 {
     aCond = rStr;
 }
-/*-----------------06.03.98 16:16-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwDBNextSetField::QueryValue( uno::Any& rAny, BYTE nMId ) const
 /*N*/ {
 /*N*/     nMId &= ~CONVERT_TWIPS;
@@ -637,9 +619,7 @@ void SwDBNextSetField::SetPar1(const String& rStr)
 /*N*/ 	}
 /*N*/ 	return bRet;
 /*N*/ }
-/*-----------------06.03.98 16:16-------------------
 
---------------------------------------------------*/
 BOOL SwDBNextSetField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId )
 {
     nMId &= ~CONVERT_TWIPS;
@@ -655,29 +635,14 @@ BOOL SwDBNextSetField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nM
     return bRet;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-/*
-String SwDBNextSetField::GetPar2() const
-{
-    return GetDBName();
-}
-
-void SwDBNextSetField::SetPar2(const String& rStr)
-{
-    GetDBName() = rStr;
-}
-*/
-
 /*--------------------------------------------------------------------
     Beschreibung: Datensatz mit bestimmter ID
  --------------------------------------------------------------------*/
 
-/*N*/ SwDBNumSetFieldType::SwDBNumSetFieldType() :
-/*N*/ 	SwFieldType( RES_DBNUMSETFLD )
-/*N*/ {
-/*N*/ }
+SwDBNumSetFieldType::SwDBNumSetFieldType()
+    : SwFieldType( RES_DBNUMSETFLD )
+{
+}
 
 //------------------------------------------------------------------------------
 
@@ -723,7 +688,7 @@ void SwDBNextSetField::SetPar2(const String& rStr)
 /*N*/ {
 /*N*/ 	SwNewDBMgr* pMgr = pDoc->GetNewDBMgr();
 /*N*/ 	const SwDBData& aTmpData = GetDBData();
-/*N*/ 
+/*N*/
 /*N*/ 	if( bCondValid && pMgr && pMgr->IsInMerge() &&
 /*N*/                         pMgr->IsDataSourceOpen(aTmpData.sDataSource, aTmpData.sCommand, sal_True))
 /*N*/ 	{	// Bedingug OK -> aktuellen Set einstellen
@@ -758,9 +723,7 @@ void SwDBNumSetField::SetPar2(const String& rStr)
 {
     aPar2 = rStr;
 }
-/*-----------------06.03.98 16:16-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwDBNumSetField::QueryValue( ::com::sun::star::uno::Any& rAny, BYTE nMId ) const
 /*N*/ {
 /*N*/     nMId &= ~CONVERT_TWIPS;
@@ -778,9 +741,7 @@ void SwDBNumSetField::SetPar2(const String& rStr)
 /*N*/ 	}
 /*N*/ 	return bRet;
 /*N*/ }
-/*-----------------06.03.98 16:16-------------------
 
---------------------------------------------------*/
 BOOL    SwDBNumSetField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId )
 {
     nMId &= ~CONVERT_TWIPS;
@@ -792,7 +753,7 @@ BOOL    SwDBNumSetField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE
         break;
     case FIELD_PROP_FORMAT:
         {
-            sal_Int32 nVal;
+            sal_Int32 nVal(0);
             rAny >>= nVal;
             aPar2 = String::CreateFromInt32(nVal);
         }
@@ -816,7 +777,7 @@ BOOL    SwDBNumSetField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE
 
 /*N*/ String SwDBNameFieldType::Expand(ULONG nFmt) const
 /*N*/ {
-/*N*/ 	ASSERT( nFmt >= FF_BEGIN && nFmt < FF_END, "Expand: kein guelt. Fmt!" );
+/*N*/ 	OSL_ENSURE( nFmt >= FF_BEGIN && nFmt < FF_END, "Expand: kein guelt. Fmt!" );
 /*N*/ 	const SwDBData aData = pDoc->GetDBData();
 /*N*/ 	String sRet(aData.sDataSource);
 /*N*/ 	sRet += '.';
@@ -862,16 +823,12 @@ BOOL    SwDBNumSetField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE
 /*N*/ 	return pTmp;
 /*N*/ }
 
-/*-----------------06.03.98 16:16-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwDBNameField::QueryValue( ::com::sun::star::uno::Any& rAny, BYTE nMId ) const
 /*N*/ {
 /*N*/ 	return SwDBNameInfField::QueryValue(rAny, nMId );
 /*N*/ }
-/*-----------------06.03.98 16:16-------------------
 
---------------------------------------------------*/
 BOOL SwDBNameField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId )
 {
     return SwDBNameInfField::PutValue(rAny, nMId );
@@ -913,7 +870,6 @@ BOOL SwDBNameField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId
 /*?*/ 		return aEmptyStr;
 /*N*/ 	else
 /*N*/ 		return FormatNumber((USHORT)nNumber, GetFormat());
-/*N*/ 	//return(nNumber == 0 ? aEmptyStr : FormatNumber(nNumber, GetFormat()));
 /*N*/ }
 
 //------------------------------------------------------------------------------
@@ -921,9 +877,9 @@ BOOL SwDBNameField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId
 /*N*/ void SwDBSetNumberField::Evaluate(SwDoc* pDoc)
 /*N*/ {
 /*N*/ 	SwNewDBMgr* pMgr = pDoc->GetNewDBMgr();
-/*N*/ 
+/*N*/
 /*N*/     const SwDBData& aTmpData = GetDBData();
-/*N*/     if (!pMgr || !pMgr->IsInMerge() || 
+/*N*/     if (!pMgr || !pMgr->IsInMerge() ||
 /*N*/         !pMgr->IsDataSourceOpen(aTmpData.sDataSource, aTmpData.sCommand, sal_False))
 /*N*/         return;
 /*N*/     nNumber = pMgr->GetSelectedRecordId();
@@ -941,9 +897,7 @@ BOOL SwDBNameField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId
 /*N*/     pTmp->SetSubType(GetSubType());
 /*N*/ 	return pTmp;
 /*N*/ }
-/*-----------------06.03.98 16:15-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwDBSetNumberField::QueryValue( ::com::sun::star::uno::Any& rAny, BYTE nMId ) const
 /*N*/ {
 /*N*/ 	BOOL bRet = TRUE;
@@ -961,9 +915,7 @@ BOOL SwDBNameField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId
 /*N*/ 	}
 /*N*/ 	return bRet;
 /*N*/ }
-/*-----------------06.03.98 16:15-------------------
 
---------------------------------------------------*/
 BOOL SwDBSetNumberField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE nMId )
 {
     BOOL bRet = TRUE;
@@ -972,7 +924,7 @@ BOOL SwDBSetNumberField::PutValue( const ::com::sun::star::uno::Any& rAny, BYTE
     {
     case FIELD_PROP_USHORT1:
         {
-            sal_Int16 nSet;
+            sal_Int16 nSet(0);
             rAny >>= nSet;
             if(nSet < (INT16) SVX_NUMBER_NONE )
                 SetFormat(nSet);
