@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -36,11 +37,9 @@
 
 #include <rtl/tencinfo.h>
 #include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <svtools/textview.hxx>
-#ifndef _SCRBAR_HXX //autogen
 #include <vcl/scrbar.hxx>
-#endif
 #include <tools/stream.hxx>
 #include <tools/time.hxx>
 #include <osl/file.hxx>
@@ -55,7 +54,8 @@
 #include "xmlfileview.hrc"
 #include "xmlfilterhelpids.hrc"
 
-using namespace rtl;
+#include <deque>
+
 using namespace osl;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::beans;
@@ -64,6 +64,8 @@ using namespace com::sun::star::io;
 using namespace com::sun::star::xml;
 using namespace com::sun::star::xml::sax;
 
+using ::rtl::OUString;
+
 
 #define MAX_SYNTAX_HIGHLIGHT 20
 #define MAX_HIGHLIGHTTIME 200
@@ -72,13 +74,12 @@ using namespace com::sun::star::xml::sax;
 
 struct SwTextPortion
 {
-    USHORT nLine;
-    USHORT nStart, nEnd;
+    sal_uInt16 nLine;
+    sal_uInt16 nStart, nEnd;
     svtools::ColorConfigEntry eType;
 };
 
-SV_DECL_VARARR(SwTextPortions, SwTextPortion,16,16)
-SV_IMPL_VARARR(SwTextPortions, SwTextPortion);
+typedef std::deque<SwTextPortion> SwTextPortions;
 
 class XMLErrorHandler : public ::cppu::WeakImplHelper1< XErrorHandler >
 {
@@ -104,7 +105,7 @@ XMLErrorHandler::XMLErrorHandler( XMLSourceFileDialog* pParent, ListBox& rListBo
 // XMLErrorHandler
 void SAL_CALL XMLErrorHandler::error( const Any& aSAXParseException ) throw (SAXException, RuntimeException)
 {
-    vos::OGuard aGuard( Application::GetSolarMutex() );
+    ::SolarMutexGuard aGuard;
 
     SAXParseException e;
     if( aSAXParseException >>= e )
@@ -112,14 +113,14 @@ void SAL_CALL XMLErrorHandler::error( const Any& aSAXParseException ) throw (SAX
         String sErr( String::CreateFromInt32( e.LineNumber ) );
         sErr += String( RTL_CONSTASCII_USTRINGPARAM( " : " ) );
         sErr += String( e.Message );
-        USHORT nEntry = mrListBox.InsertEntry( sErr );
-        mrListBox.SetEntryData( nEntry, (void*)e.LineNumber );
+        sal_uInt16 nEntry = mrListBox.InsertEntry( sErr );
+        mrListBox.SetEntryData( nEntry, (void*)(sal_IntPtr)e.LineNumber );
     }
 }
 
 void SAL_CALL XMLErrorHandler::fatalError( const Any& aSAXParseException ) throw (SAXException, RuntimeException)
 {
-    vos::OGuard aGuard( Application::GetSolarMutex() );
+    ::SolarMutexGuard aGuard;
 
     SAXParseException e;
     if( aSAXParseException >>= e )
@@ -127,24 +128,13 @@ void SAL_CALL XMLErrorHandler::fatalError( const Any& aSAXParseException ) throw
         String sErr( String::CreateFromInt32( e.LineNumber ) );
         sErr += String( RTL_CONSTASCII_USTRINGPARAM( " : " ) );
         sErr += String( e.Message );
-        USHORT nEntry = mrListBox.InsertEntry( sErr );
-        mrListBox.SetEntryData( nEntry, (void*)e.LineNumber );
+        sal_uInt16 nEntry = mrListBox.InsertEntry( sErr );
+        mrListBox.SetEntryData( nEntry, (void*)(sal_IntPtr)e.LineNumber );
     }
 }
 
 void SAL_CALL XMLErrorHandler::warning( const Any& /* aSAXParseException */ ) throw (SAXException, RuntimeException)
 {
-/*
-    SAXParseException e;
-    if( aSAXParseException >>= e )
-    {
-        String sErr( String::CreateFromInt32( e.LineNumber ) );
-        sErr += String( RTL_CONSTASCII_USTRINGPARAM( " : " ) );
-        sErr += String( e.Message );
-        USHORT nEntry = mrListBox.InsertEntry( sErr );
-        mrListBox.SetEntryData( nEntry, (void*)e.LineNumber );
-    }
-*/
 }
 
 
@@ -343,14 +333,14 @@ void XMLFileWindow::CreateTextEngine()
 
     pTextEngine = new TextEngine;
     pTextView = new TextView( pTextEngine, pOutWin );
-    pTextView->SetAutoIndentMode(TRUE);
+    pTextView->SetAutoIndentMode(sal_True);
     pOutWin->SetTextView(pTextView);
 
-    pTextEngine->SetUpdateMode( FALSE );
+    pTextEngine->SetUpdateMode( sal_False );
     pTextEngine->InsertView( pTextView );
 
     Font aFont;
-    aFont.SetTransparent( FALSE );
+    aFont.SetTransparent( sal_False );
     aFont.SetFillColor( rCol );
     SetPointFont( aFont );
     aFont = GetFont();
@@ -361,10 +351,9 @@ void XMLFileWindow::CreateTextEngine()
     aSyntaxIdleTimer.SetTimeout( SYNTAX_HIGHLIGHT_TIMEOUT );
     aSyntaxIdleTimer.SetTimeoutHdl( LINK( this, XMLFileWindow, SyntaxTimerHdl ) );
 
-    pTextEngine->EnableUndo( FALSE );
-    pTextEngine->SetUpdateMode( TRUE );
+    pTextEngine->EnableUndo( sal_False );
+    pTextEngine->SetUpdateMode( sal_True );
 
-//	pTextView->ShowCursor( TRUE, TRUE );
     pTextView->HideCursor();
 
     InitScrollBars();
@@ -399,14 +388,14 @@ IMPL_LINK(XMLFileWindow, ScrollHdl, ScrollBar*, pScroll)
     {
         long nDiff = pTextView->GetStartDocPos().Y() - pScroll->GetThumbPos();
         GetTextView()->Scroll( 0, nDiff );
-        pTextView->ShowCursor( FALSE, TRUE );
+        pTextView->ShowCursor( sal_False, sal_True );
         pScroll->SetThumbPos( pTextView->GetStartDocPos().Y() );
     }
     else
     {
         long nDiff = pTextView->GetStartDocPos().X() - pScroll->GetThumbPos();
         GetTextView()->Scroll( nDiff, 0 );
-        pTextView->ShowCursor( FALSE, TRUE );
+        pTextView->ShowCursor( sal_False, sal_True );
         pScroll->SetThumbPos( pTextView->GetStartDocPos().X() );
     }
     return 0;
@@ -431,7 +420,7 @@ void XMLFileWindow::Notify( SfxBroadcaster& /* rBC */, const SfxHint& rHint )
         }
         else if( rTextHint.GetId() == TEXT_HINT_FORMATPARA )
         {
-            DoDelayedSyntaxHighlight( (USHORT)rTextHint.GetValue() );
+            DoDelayedSyntaxHighlight( (sal_uInt16)rTextHint.GetValue() );
         }
     }
 }
@@ -548,7 +537,7 @@ void XMLSourceFileDialog::ShowWindow( const rtl::OUString& rFileName, const filt
         mpTextWindow = new XMLFileWindow( this );
         maLBOutput.Hide();
         maLBOutput.Clear();
-        maPBValidate.Enable(TRUE);
+        maPBValidate.Enable(sal_True);
         Resize();
     }
 
@@ -567,10 +556,6 @@ void XMLSourceFileDialog::Resize()
     Size aButton( maPBValidate.GetSizePixel() );
 
     Size aDialogSize( GetOutputSizePixel() );
-
-//	Point aButtonPos( aSpacing.X(), aSpacing.Y() );
-//	maPBValidate.SetPosSizePixel( aButtonPos, aButton );
-
     Size aOutputSize( aDialogSize.Width(), bOutputVisible ? mnOutputHeight : 0 );
 
     Point aTextWindowPos( 0, 2* aSpacing.Y() + aButton.Height() );
@@ -588,7 +573,7 @@ void XMLSourceFileDialog::Resize()
 
 IMPL_LINK(XMLSourceFileDialog, SelectHdl_Impl, ListBox *, pListBox )
 {
-    USHORT nEntry = pListBox->GetSelectEntryPos();
+    sal_uInt16 nEntry = pListBox->GetSelectEntryPos();
     if( LISTBOX_ENTRY_NOTFOUND != nEntry )
     {
         int nLine = (int)(sal_IntPtr)pListBox->GetEntryData(nEntry);
@@ -614,16 +599,16 @@ void XMLSourceFileDialog::onValidate()
     EnterWait();
 
     maLBOutput.Show();
-    maPBValidate.Enable(FALSE);
+    maPBValidate.Enable(sal_False);
     Resize();
 
     try
     {
-        Reference< XImportFilter > xImporter( mxMSF->createInstance( OUString::createFromAscii( "com.sun.star.documentconversion.XSLTValidate" ) ), UNO_QUERY );
+        Reference< XImportFilter > xImporter( mxMSF->createInstance( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.documentconversion.XSLTValidate" )) ), UNO_QUERY );
         if( xImporter.is() )
         {
             osl::File aInputFile( maFileURL );
-            /* osl::File::RC rc = */ aInputFile.open( OpenFlag_Read );
+            /* osl::File::RC rc = */ aInputFile.open( osl_File_OpenFlag_Read );
 
             Reference< XInputStream > xIS( new comphelper::OSLInputStreamWrapper( aInputFile ) );
             
@@ -650,14 +635,14 @@ void XMLSourceFileDialog::onValidate()
     catch(Exception& e)
     {
         String sErr( e.Message );
-        USHORT nEntry = maLBOutput.InsertEntry( sErr );
+        sal_uInt16 nEntry = maLBOutput.InsertEntry( sErr );
         maLBOutput.SetEntryData( nEntry, (void*)-1 );
     }
 
     if( 0 == maLBOutput.GetEntryCount() )
     {
         String sErr( RESID( STR_NO_ERRORS_FOUND ) );
-        USHORT nEntry = maLBOutput.InsertEntry( sErr );
+        sal_uInt16 nEntry = maLBOutput.InsertEntry( sErr );
         maLBOutput.SetEntryData( nEntry, (void*)-1 );
     }
 
@@ -678,8 +663,6 @@ void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
     const sal_Unicode cCloseBracket= '>';
     const sal_Unicode cSlash		= '/';
     const sal_Unicode cExclamation = '!';
-//	const sal_Unicode cQuote		= '"';
-//	const sal_Unicode cSQuote      = '\'';
     const sal_Unicode cMinus		= '-';
     const sal_Unicode cSpace		= ' ';
     const sal_Unicode cTab			= 0x09;
@@ -687,12 +670,12 @@ void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
     const sal_Unicode cCR          = 0x0d;
 
 
-    const USHORT nStrLen = rSource.Len();
-    USHORT nInsert = 0;			// Anzahl der eingefuegten Portions
-    USHORT nActPos = 0;			//Position, an der '<' gefunden wurde
-    USHORT nOffset = 0; 		//Offset von nActPos zur '<'
-    USHORT nPortStart = USHRT_MAX; 	// fuer die TextPortion
-    USHORT nPortEnd  = 	0;  //
+    const sal_uInt16 nStrLen = rSource.Len();
+    sal_uInt16 nInsert = 0;			// Number of inserted Portions
+    sal_uInt16 nActPos = 0;			// Position, at the '<' was found
+    sal_uInt16 nOffset = 0; 		// Offset of nActPos for '<'
+    sal_uInt16 nPortStart = USHRT_MAX; 	// For the TextPortion
+    sal_uInt16 nPortEnd  = 	0;  //
     SwTextPortion aText;
     while(nActPos < nStrLen)
     {
@@ -709,7 +692,8 @@ void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
                     aText.nStart += 1;
                 aText.nEnd = nActPos - 1;
                 aText.eType = svtools::HTMLUNKNOWN;
-                aPortionList.Insert(aText, nInsert++);
+                aPortionList.push_back( aText );
+                nInsert++;
             }
             sal_Unicode cFollowFirst = rSource.GetChar((xub_StrLen)(nActPos + 1));
             sal_Unicode cFollowNext = rSource.GetChar((xub_StrLen)(nActPos + 2));
@@ -736,7 +720,7 @@ void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
             if(svtools::HTMLUNKNOWN == eFoundType)
             {
                 //jetzt koennte hier ein keyword folgen
-                USHORT nSrchPos = nActPos;
+                sal_uInt16 nSrchPos = nActPos;
                 while(++nSrchPos < nStrLen - 1)
                 {
                     sal_Unicode cNext = rSource.GetChar(nSrchPos);
@@ -755,42 +739,29 @@ void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
                     //irgend ein String wurde gefunden
                     String sToken = rSource.Copy(nActPos + 1, nSrchPos - nActPos - 1 );
                     sToken.ToUpperAscii();
-//					int nToken = ::GetHTMLToken(sToken);
-//					if(nToken)
                     {
                         //Token gefunden
                         eFoundType = svtools::HTMLKEYWORD;
                         nPortEnd = nSrchPos;
                         nPortStart = nActPos;
                     }
-/*
-                    else
-                    {
-                        //was war das denn?
-#ifdef DEBUG
-                        DBG_ERROR("Token nicht erkannt!")
-                        DBG_ERROR(ByteString(sToken, gsl_getSystemTextEncoding()).GetBuffer())
-#endif
-                    }
-*/
-
                 }
             }
             // jetzt muss noch '>' gesucht werden
             if(svtools::HTMLUNKNOWN != eFoundType)
             {
-                BOOL bFound = FALSE;
-                for(USHORT i = nPortEnd; i < nStrLen; i++)
+                sal_Bool bFound = sal_False;
+                for(sal_uInt16 i = nPortEnd; i < nStrLen; i++)
                     if(cCloseBracket == rSource.GetChar(i))
                     {
-                        bFound = TRUE;
+                        bFound = sal_True;
                         nPortEnd = i;
                         break;
                     }
                 if(!bFound && (eFoundType == svtools::HTMLCOMMENT))
                 {
                     // Kommentar ohne Ende in dieser Zeile
-                    bFound  = TRUE;
+                    bFound  = sal_True;
                     nPortEnd = nStrLen - 1;
                 }
 
@@ -801,7 +772,8 @@ void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
                     aText2.nStart = nPortStart + 1;
                     aText2.nEnd = nPortEnd;
                     aText2.eType = eFoundType;
-                    aPortionList.Insert(aText2, nInsert++);
+                    aPortionList.push_back( aText2 ); 
+                    nInsert++;		
                     eFoundType = svtools::HTMLUNKNOWN;
                 }
 
@@ -815,25 +787,26 @@ void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
         aText.nStart = nPortEnd + 1;
         aText.nEnd = nActPos - 1;
         aText.eType = svtools::HTMLUNKNOWN;
-        aPortionList.Insert(aText, nInsert++);
+        aPortionList.push_back( aText );
+        nInsert++;
     }
 }
 
-void XMLFileWindow::DoDelayedSyntaxHighlight( USHORT nPara )
+void XMLFileWindow::DoDelayedSyntaxHighlight( sal_uInt16 nPara )
 {
     if ( !bHighlighting )
     {
-        aSyntaxLineTable.Insert( nPara, (void*)(USHORT)1 );
+        aSyntaxLineTable.Insert( nPara, (void*)(sal_uInt16)1 );
         aSyntaxIdleTimer.Start();
     }
 }
 
-void XMLFileWindow::ImpDoHighlight( const String& rSource, USHORT nLineOff )
+void XMLFileWindow::ImpDoHighlight( const String& rSource, sal_uInt16 nLineOff )
 {
     SwTextPortions aPortionList;
     lcl_Highlight(rSource, aPortionList);
 
-    USHORT nCount = aPortionList.Count();
+    size_t nCount = aPortionList.size();
     if ( !nCount )
         return;
 
@@ -841,7 +814,7 @@ void XMLFileWindow::ImpDoHighlight( const String& rSource, USHORT nLineOff )
     if ( rLast.nStart > rLast.nEnd ) 	// Nur bis Bug von MD behoeben
     {
         nCount--;
-        aPortionList.Remove( nCount);
+        aPortionList.pop_back();
         if ( !nCount )
             return;
     }
@@ -850,14 +823,14 @@ void XMLFileWindow::ImpDoHighlight( const String& rSource, USHORT nLineOff )
     // Wenn haufig gleiche Farbe, dazwischen Blank ohne Farbe,
     // ggf. zusammenfassen, oder zumindest das Blank,
     // damit weniger Attribute
-    BOOL bOptimizeHighlight = TRUE; // war in der BasicIDE static
+    sal_Bool bOptimizeHighlight = sal_True; // war in der BasicIDE static
     if ( bOptimizeHighlight )
     {
         // Es muessen nur die Blanks und Tabs mit attributiert werden.
         // Wenn zwei gleiche Attribute hintereinander eingestellt werden,
         // optimiert das die TextEngine.
-        USHORT nLastEnd = 0;
-        for ( USHORT i = 0; i < nCount; i++ )
+        sal_uInt16 nLastEnd = 0;
+        for ( size_t i = 0; i < nCount; i++ )
         {
             SwTextPortion& r = aPortionList[i];
             DBG_ASSERT( r.nLine == aPortionList[0].nLine, "doch mehrere Zeilen ?" );
@@ -877,19 +850,18 @@ void XMLFileWindow::ImpDoHighlight( const String& rSource, USHORT nLineOff )
     }
 
     svtools::ColorConfig aConfig;
-    for ( USHORT i = 0; i < aPortionList.Count(); i++ )
+    for ( size_t i = 0; i < aPortionList.size(); i++ )
     {
         SwTextPortion& r = aPortionList[i];
         if ( r.nStart > r.nEnd ) 	// Nur bis Bug von MD behoeben
             continue;
-//		USHORT nCol = r.eType;
         if(r.eType !=  svtools::HTMLSGML    &&
             r.eType != svtools::HTMLCOMMENT &&
             r.eType != svtools::HTMLKEYWORD &&
             r.eType != svtools::HTMLUNKNOWN)
                 r.eType = (svtools::ColorConfigEntry)svtools::HTMLUNKNOWN;
         Color aColor((ColorData)aConfig.GetColorValue((svtools::ColorConfigEntry)r.eType).nColor);
-        USHORT nLine = nLineOff+r.nLine; //
+        sal_uInt16 nLine = nLineOff+r.nLine; //
         pTextEngine->SetAttrib( TextAttribFontColor( aColor ), nLine, r.nStart, r.nEnd+1 );
     }
 }
@@ -898,20 +870,20 @@ IMPL_LINK( XMLFileWindow, SyntaxTimerHdl, Timer *, pTimer )
 {
     Time aSyntaxCheckStart;
     DBG_ASSERT( pTextView, "Noch keine View, aber Syntax-Highlight ?!" );
-    pTextEngine->SetUpdateMode( FALSE );
+    pTextEngine->SetUpdateMode( sal_False );
 
-    bHighlighting = TRUE;
-    USHORT nLine;
-    USHORT nCount  = 0;
+    bHighlighting = sal_True;
+    sal_uInt16 nLine;
+    sal_uInt16 nCount  = 0;
     // zuerst wird der Bereich um dem Cursor bearbeitet
     TextSelection aSel = pTextView->GetSelection();
-    USHORT nCur = (USHORT)aSel.GetStart().GetPara();
+    sal_uInt16 nCur = (sal_uInt16)aSel.GetStart().GetPara();
     if(nCur > 40)
         nCur -= 40;
     else
         nCur = 0;
     if(aSyntaxLineTable.Count())
-        for(USHORT i = 0; i < 80 && nCount < 40; i++, nCur++)
+        for(sal_uInt16 i = 0; i < 80 && nCount < 40; i++, nCur++)
         {
             void * p = aSyntaxLineTable.Get(nCur);
             if(p)
@@ -933,9 +905,9 @@ IMPL_LINK( XMLFileWindow, SyntaxTimerHdl, Timer *, pTimer )
     void* p = aSyntaxLineTable.First();
     while ( p && nCount < MAX_SYNTAX_HIGHLIGHT)
     {
-        nLine = (USHORT)aSyntaxLineTable.GetCurKey();
+        nLine = (sal_uInt16)aSyntaxLineTable.GetCurKey();
         DoSyntaxHighlight( nLine );
-        USHORT nC = (USHORT)aSyntaxLineTable.GetCurKey();
+        sal_uInt16 nC = (sal_uInt16)aSyntaxLineTable.GetCurKey();
         p = aSyntaxLineTable.Next();
         aSyntaxLineTable.Remove(nC);
         nCount ++;
@@ -949,9 +921,9 @@ IMPL_LINK( XMLFileWindow, SyntaxTimerHdl, Timer *, pTimer )
     // waehrend des Highlightings funktionierte das Scrolling nicht
     TextView* pTmp = pTextEngine->GetActiveView();
     pTextEngine->SetActiveView(0);
-    pTextEngine->SetUpdateMode( TRUE );
+    pTextEngine->SetUpdateMode( sal_True );
     pTextEngine->SetActiveView(pTmp);
-    pTextView->ShowCursor(FALSE, FALSE);
+    pTextView->ShowCursor(sal_False, sal_False);
 
     if(aSyntaxLineTable.Count() && !pTimer->IsActive())
         pTimer->Start();
@@ -961,12 +933,12 @@ IMPL_LINK( XMLFileWindow, SyntaxTimerHdl, Timer *, pTimer )
     nCurTextWidth = pTextEngine->CalcTextWidth() + 25;	// kleine Toleranz
     if ( nCurTextWidth != nPrevTextWidth )
         SetScrollBarRanges();
-    bHighlighting = FALSE;
+    bHighlighting = sal_False;
 
     return 0;
 }
 
-void XMLFileWindow::DoSyntaxHighlight( USHORT nPara )
+void XMLFileWindow::DoSyntaxHighlight( sal_uInt16 nPara )
 {
     // Durch das DelayedSyntaxHighlight kann es passieren,
     // dass die Zeile nicht mehr existiert!
@@ -974,17 +946,19 @@ void XMLFileWindow::DoSyntaxHighlight( USHORT nPara )
     {
         pTextEngine->RemoveAttribs( nPara );
         String aSource( pTextEngine->GetText( nPara ) );
-        pTextEngine->SetUpdateMode( FALSE );
+        pTextEngine->SetUpdateMode( sal_False );
         ImpDoHighlight( aSource, nPara );
         // os: #43050# hier wird ein TextView-Problem umpopelt:
         // waehrend des Highlightings funktionierte das Scrolling nicht
         TextView* pTmp = pTextEngine->GetActiveView();
-        pTmp->SetAutoScroll(FALSE);
+        pTmp->SetAutoScroll(sal_False);
         pTextEngine->SetActiveView(0);
-        pTextEngine->SetUpdateMode( TRUE );
+        pTextEngine->SetUpdateMode( sal_True );
         pTextEngine->SetActiveView(pTmp);
         // Bug 72887 show the cursor
-        pTmp->SetAutoScroll(TRUE);
-        pTmp->ShowCursor( FALSE/*pTmp->IsAutoScroll()*/ );
+        pTmp->SetAutoScroll(sal_True);
+        pTmp->ShowCursor( sal_False/*pTmp->IsAutoScroll()*/ );
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
